@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-#include "mongoc-config.h"
+#include <mongoc/mongoc-config.h>
 
 #ifdef MONGOC_ENABLE_SSL_OPENSSL
 
@@ -29,18 +29,18 @@
 
 #include <string.h>
 
-#include "mongoc-http-private.h"
-#include "mongoc-init.h"
-#include "mongoc-openssl-private.h"
-#include "mongoc-socket.h"
-#include "mongoc-ssl.h"
-#include "mongoc-stream-tls-openssl-private.h"
-#include "mongoc-thread-private.h"
-#include "mongoc-trace-private.h"
-#include "mongoc-util-private.h"
+#include <mongoc/mongoc-http-private.h>
+#include <mongoc/mongoc-init.h>
+#include <mongoc/mongoc-openssl-private.h>
+#include <mongoc/mongoc-socket.h>
+#include <mongoc/mongoc-ssl.h>
+#include <mongoc/mongoc-stream-tls-openssl-private.h>
+#include <mongoc/mongoc-thread-private.h>
+#include <mongoc/mongoc-trace-private.h>
+#include <mongoc/mongoc-util-private.h>
 
 #ifdef MONGOC_ENABLE_OCSP_OPENSSL
-#include "mongoc-ocsp-cache-private.h"
+#include <mongoc/mongoc-ocsp-cache-private.h>
 #endif
 
 #ifdef _WIN32
@@ -147,7 +147,7 @@ _mongoc_openssl_import_cert_store (LPWSTR store_name, DWORD dwFlags, X509_STORE
                      (LPTSTR) &msg,
                      0,
                      NULL);
-      MONGOC_ERROR ("Can't open CA store: 0x%.8X: '%s'", GetLastError (), msg);
+      MONGOC_ERROR ("Can't open CA store: 0x%.8lX: '%s'", GetLastError (), msg);
       LocalFree (msg);
       return false;
    }
